#
# spec file for package python-pyUSID
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename pyUSID
%{?!python_module:%define python_module() python-%{**} python-%{**}}
Name:           python-pyUSID
Version:        0.0.9
Release:        2.2
Summary:        Framework for processing scientific data (USID)
License:        MIT
URL:            https://pycroscopy.github.io/pyUSID/
Source0:        https://github.com/pycroscopy/pyUSID/archive/%{version}.tar.gz#/%{packagename}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix_tests_h5py-3.0.patch andythe_great@pm.me -- Fix broken tests due to h5py 3.0, should be fix in next release.
Patch0:         fix_tests_h5py-3.0.patch
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module cytoolz}
BuildRequires:  %{python_module dask >= 0.10}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module h5py >= 2.6.0}
BuildRequires:  %{python_module ipywidgets >= 5.2.2}
BuildRequires:  %{python_module joblib >= 0.11.0}
BuildRequires:  %{python_module matplotlib >= 2.0.0}
BuildRequires:  %{python_module numpy >= 1.10}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sidpy >= 0.0.1}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module toolz}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-cytoolz
Requires:       python-dask >= 0.10
Requires:       python-dask-array
Requires:       python-h5py >= 2.6.0
Requires:       python-ipywidgets >= 5.2.2
Requires:       python-joblib >= 0.11.0
Requires:       python-matplotlib >= 2.0.0
Requires:       python-numpy >= 1.10
Requires:       python-psutil
Requires:       python-sidpy >= 0.0.1
Requires:       python-six
Requires:       python-toolz
BuildArch:      noarch
%python_subpackages

%description
Framework for storing, visualizing, and processing Universal Spectroscopic
and Imaging Data (USID).

%prep
%setup -q -n %{packagename}-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*egg-info
%{python_sitelib}/%{packagename}


%changelog
* Thu Dec 10 2020 andy great <andythe_great@pm.me>
- Add fix_tests_h5py-3.0.patch to fix broken test from h5py 3.0.
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.9.
  * Fixed bug regarding dask array transpose in USIDataset
  * Not writing region references for ancillary datasets anymore
  * Moved USID agnostic functions in pyUSID.io.reg_ref.py,
    pyUSID.io.dtype_utils.py, pyUSID.io.hdf_utils.simple.py,
    pyUSID.viz.plot_utils.py, pyUSID.viz.jupyter_utils.py,
    pyUSID.processing.comp_utils.py to new package - sidpy
  * Importing sidpy instead of local code copies for these modules
  * Enabling multiple instances of Process class to be executed in
    parallel via each MPI rank - ensemble / embarrassingly parallel
    processing
  * No longer pushing tests when deploying via pip
- Remove fix_tests_dir_in_site_package.patch
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the download url
* Thu Aug  6 2020 andy great <andythe_great@pm.me>
- Initial package release.
